@@ -161,13 +161,13 @@ class ProgramTester:
 		
 	def test_program_outputFiles(self, i, print_diff = True):
 		# Get the command line arguments from ./solution/command_arguments.txt
-		with open("solution/command_arguments.txt") as f:
+		with open(os.environ['COMMANDARGS']) as f:
 			# Get the ith line of the file
 			lines = f.readlines()
 			l = self.remove_text_inside_brackets(lines[i]).strip()
 		# Execute the student's program with the given command line arguments
-		out = self.execute_program(l.format("student_", i))
-		# Compare between the two files
-		studentOut = self.read_output_file("student_output_{}.txt".format(i))
-		solutionOut = self.read_output_file("solution/output_{}.txt".format(i))
-		return self.compare_output(studentOut, solutionOut, print_diff)
\ No newline at end of file
+		out = self.execute_program(l)
+		# Compare between the two files 
+		studentOut = self.read_output_file("sol_{}.txt".format(i))
+		solutionOut = self.read_output_file("./tester/solution/sol_{}.txt".format(i))
+		return self.compare_output(studentOut, solutionOut, print_diff)
